pytilities.aop.aspects.immutableaspect — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »
- pytilities.aop.aspects »

# pytilities.aop.aspects.immutableaspect

class `pytilities.aop.aspects.immutableaspect.` `ImmutableAspect`(attributes)

  Aspect that makes given attributes immutable.

  It will raise ImmutabileAttributeException when the value of one of the immutable attributes changes by using one of its public attributes.

  It raises after the modification is done, it doesn’t actually prevent it.

  Can only be applied to AOPMeta objects.

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »
- pytilities.aop.aspects »